@@ -9,7 +9,7 @@ use Sys::Hostname 'hostname';
 
 has 'mysql';
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub dequeue {
   my ($self, $id, $wait, $options) = @_;
@@ -735,7 +735,7 @@ Minion::Backend::mysql
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -1151,7 +1151,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexander Nalobin Brian Medley Doug Bell Olaf Alders Zoffix Znet
+=for stopwords Alexander Nalobin Olaf Alders Zoffix Znet
 
 =over 4
 
@@ -1161,18 +1161,6 @@ Alexander Nalobin <nalobin@reg.ru>
 
 =item *
 
-Brian Medley <bpm@pxe-server.scnet.net>
-
-=item *
-
-Brian Medley <pub-github@bmedley.org>
-
-=item *
-
-Doug Bell <doug@preaction.me>
-
-=item *
-
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
